System.register([], (function (exports) {
	'use strict';
	return {
		execute: (function () {

			const __icon__ = exports('default', {});

		})
	};
}));
